#!/bin/bash

# https://tukaani.org/xz/xz-5.2.3.tar.bz2

P=xz
V=5.2.3
B=1

set -e

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	cmd /c set >$TEMP/srcenv
	cmd /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$TEMP/dstenv
	diff -u $TEMP/srcenv $TEMP/dstenv | sed -f $D/envdiff.sed >$TEMP/diffenv
	. $TEMP/diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $TEMP/srcenv $TEMP/dstenv $TEMP/diffenv
}

export ARCH=$1
case "$ARCH" in
x86)
	export OSGEO4W_ROOT="C:\\OSGeo4W"
	VCARCH=x86
	TARGETARCH=Win32
	;;

x86_64)
	export OSGEO4W_ROOT="C:\\OSGeo4W64"
	VCARCH=x64
	TARGETARCH=x64
	;;

*)
	echo "Unsupported arch $ARCH" >&2
	exit 1
	;;
esac

export D=$PWD
export P V B ARCH

R=../../../$ARCH/release/$P

mkdir -p $R/$P-devel

set -x

fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat $VCARCH
PATH=/cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/Common7/IDE:$PATH

cd ../windows

devenv xz_win.sln /upgrade
devenv xz_win.sln /Build "Release|$TARGETARCH" /out ..\\osgeo4w\\build-$TARGETARCH.log

cd ../osgeo4w
mkdir -p install-$ARCH
cd install-$ARCH
mkdir -p bin lib include

cp ../../windows/Release/$TARGETARCH/liblzma_dll/liblzma.dll bin
cp ../../windows/Release/$TARGETARCH/liblzma_dll/liblzma.lib lib
cp -a ../../src/liblzma/api/lzma* include

cd ..

cat <<EOF >$R/setup.hint
sdesc: "XZ-format compression library"
ldesc: "XZ-format compression library"
maintainer: JuergenFischer
requires: msvcrt2015
category: Libs
EOF

cat <<EOF >$R/$P-devel/setup.hint
sdesc: "XZ-format compression library - development files"
ldesc: "XZ-format compression library - development files"
maintainer: JuergenFischer
category: Libs
requires: $P
external-source: $P
EOF

cp ../COPYING $R/$P-$V-$B.txt

tar -C install-$ARCH -cjvf $R/$P-$V-$B.tar.bz2 bin/liblzma.dll

tar -C install-$ARCH -cjvf $R/$P-devel/$P-devel-$V-$B.tar.bz2 include lib

tar -C .. -cjvf $R/$P-$V-$B-src.tar.bz2 \
	osgeo4w/package.sh \
	osgeo4w/envdiff.sed
